@@ -83,18 +83,17 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Available" : "Disponeble",
     "Not available" : "Ne disponeble",
+    "Done" : "Farita",
     "Busy" : "Okupita",
     "Out of office" : "Ekstere oficejo",
     "Unknown" : "Nekonata",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
     "Tentative" : "Nekonfirmita",
-    "Show busy times" : "Montri okupatajn tempojn",
-    "Send email" : "Sendi retpoŝtmesaĝon",
+    "Attendees" : "Ĉeestontoj",
     "Required participant" : "Bezonata partoprenanto",
     "Optional participant" : "Laŭvola partoprenanto",
     "Remove group" : "Forigi grupon",
-    "Search for emails, users or contacts" : "Serĉi por retpoŝtojn, uzantojn, aŭ kontaktojn",
     "All day" : "Tuttage",
     "Repeat" : "Ripeti",
     "never" : "neniam",
@@ -110,7 +109,6 @@ OC.L10N.register(
     "_year_::_years_" : ["Jaro","Jaroj"],
     "weekday" : "Semajntago",
     "weekend day" : "Semajnfintago",
-    "More" : "Pli",
     "on {formattedDate}" : "je la {formattedDate}",
     "Global" : "Monda",
     "Subscribe" : "Aboni",
@@ -120,14 +118,13 @@ OC.L10N.register(
     "[Tomorrow]" : "[Morgaŭ]",
     "[Yesterday]" : "[Hieraŭ]",
     "Details" : "Detaloj",
-    "Attendees" : "Ĉeestontoj",
     "Resources" : "Rimedoj",
     "Close" : "Fermi",
+    "Untitled event" : "Sentitola okazaĵo",
     "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
-    "Untitled event" : "Sentitola okazaĵo",
     "Other" : "Alia",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
@@ -137,33 +134,6 @@ OC.L10N.register(
     "Canceled" : "Nuligita",
     "Categories" : "Kategorioj",
     "Add this as a new category" : "Aldoni tion kiel novan kategorion",
-    "Commuting" : "Survoje",
-    "Bank" : "Banko",
-    "Money" : "Mono",
-    "Dog" : "Hundo",
-    "Concert" : "Koncerto",
-    "Festival" : "Festo",
-    "Theater" : "Teatro",
-    "Theatre" : "Teatro",
-    "Talk" : "Paroli",
-    "Camping" : "Tendumas",
-    "Cinema" : "Kinejo",
-    "Office" : "Oficejo",
-    "Mail" : "Retpoŝtilo",
-    "Soccer" : "Futbalo",
-    "Football" : "Futbalo",
-    "Exam" : "Ekzameno",
-    "Written test" : "Skribata testo",
-    "Oral test" : "Parolata testo",
-    "Working" : "Laboras",
-    "New Years Eve" : "Novjara vespero",
-    "Running" : "Kuras",
-    "Go for a run" : "Iru kuri",
-    "Trip" : "Vojaĝo",
-    "Collaborate" : "Kunlabori",
-    "Birthday" : "Naskiĝtago",
-    "Dinner" : "Vespermanĝo",
-    "Lunch" : "Tagmanĝo",
     "User not found" : "Netrovita uzanto"
 },
 "nplurals=2; plural=(n != 1);");
