@@ -6,11 +6,9 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
+    "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
     "Where:" : "Dónde:",
-    "Description:" : "Descripción:",
-    "Calendar" : "Calendario",
-    "New event" : "Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -20,15 +18,16 @@ OC.L10N.register(
     "Copy link" : "Copiar liga",
     "Edit" : "Editar",
     "Delete" : "Borrar",
-    "Export" : "Exportar",
-    "Share link" : "Compartir liga",
-    "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "can edit" : "puede editar",
     "New calendar" : "Nuevo calendario",
+    "Export" : "Exportar",
     "Name" : "Nombre",
     "Deleted" : "Borrado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Share link" : "Compartir liga",
+    "can edit" : "puede editar",
+    "Share with users or groups" : "Compartir con otros usuarios o grupos",
+    "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
@@ -47,43 +46,38 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Save" : "Guardar",
     "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
+    "Delete file" : "Borrar archivo",
+    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
-    "Send email" : "Enviar correo electrónico",
+    "Attendees" : "Asistentes",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
     "available" : "disponible",
-    "More" : "Más",
     "Global" : "Global",
+    "Subscribe" : "Suscribir",
     "Personal" : "Personal",
     "Details" : "Detalles",
-    "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
-    "Prev" : "Prev",
-    "Next" : "Siguiente",
     "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
-    "Categories" : "Categorías",
-    "Talk" : "Hablar",
-    "Mail" : "Correo",
-    "Birthday" : "Fecha de nacimiento"
+    "Categories" : "Categorías"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
