@@ -6,8 +6,10 @@ declare(strict_types=1);
  *
  * @author Georg Ehrke
  * @author Richard Steinmetz <richard@steinmetz.cloud>
+ * @author Jonas Heinrich <heinrich@synyx.net>
  * @copyright 2019 Georg Ehrke <oc.list@georgehrke.com>
  * @copyright Copyright (c) 2022 Informatyka Boguslawski sp. z o.o. sp.k., http://www.ib.pl/
+ * @copyright 2023 Jonas Heinrich <heinrich@synyx.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
@@ -25,8 +27,8 @@ declare(strict_types=1);
  */
 namespace OCA\Calendar\Controller;
 
+use OC\App\CompareVersion;
 use OCA\Calendar\Service\Appointments\AppointmentConfigService;
-use OCA\Calendar\Service\CategoriesService;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http\FileDisplayResponse;
@@ -46,15 +48,15 @@ class ViewController extends Controller {
 	/** @var AppointmentConfigService */
 	private $appointmentConfigService;
 
-	/** @var CategoriesService */
-	private $categoriesService;
-
 	/** @var IInitialState */
 	private $initialStateService;
 
 	/** @var IAppManager */
 	private $appManager;
 
+	/** @var CompareVersion */
+	private $compareVersion;
+
 	/** @var string */
 	private $userId;
 
@@ -64,17 +66,17 @@ class ViewController extends Controller {
 		IRequest $request,
 		IConfig $config,
 		AppointmentConfigService $appointmentConfigService,
-		CategoriesService $categoriesService,
 		IInitialState $initialStateService,
 		IAppManager $appManager,
+		CompareVersion $compareVersion,
 		?string $userId,
 		IAppData $appData) {
 		parent::__construct($appName, $request);
 		$this->config = $config;
 		$this->appointmentConfigService = $appointmentConfigService;
-		$this->categoriesService = $categoriesService;
 		$this->initialStateService = $initialStateService;
 		$this->appManager = $appManager;
+		$this->compareVersion = $compareVersion;
 		$this->userId = $userId;
 		$this->appData = $appData;
 	}
@@ -118,11 +120,17 @@ class ViewController extends Controller {
 		}
 		$canSubscribeLink = $this->config->getAppValue('dav', 'allow_calendar_link_subscriptions', 'yes') === 'yes';
 		$showResources = $this->config->getAppValue($this->appName, 'showResources', 'yes') === 'yes';
+		$publicCalendars = $this->config->getAppValue($this->appName, 'publicCalendars', '');
 
 		$talkEnabled = $this->appManager->isEnabledForUser('spreed');
 		$talkApiVersion = version_compare($this->appManager->getAppVersion('spreed'), '12.0.0', '>=') ? 'v4' : 'v1';
 		$tasksEnabled = $this->appManager->isEnabledForUser('tasks');
 
+		$circleVersion = $this->appManager->getAppVersion('circles');
+		$isCirclesEnabled = $this->appManager->isEnabledForUser('circles') === true;
+		// if circles is not installed, we use 0.0.0
+		$isCircleVersionCompatible = $this->compareVersion->isCompatible($circleVersion ? $circleVersion : '0.0.0', '22');
+
 		$this->initialStateService->provideInitialState('app_version', $appVersion);
 		$this->initialStateService->provideInitialState('event_limit', $eventLimit);
 		$this->initialStateService->provideInitialState('first_run', $firstRun);
@@ -143,8 +151,9 @@ class ViewController extends Controller {
 		$this->initialStateService->provideInitialState('appointmentConfigs', $this->appointmentConfigService->getAllAppointmentConfigurations($this->userId));
 		$this->initialStateService->provideInitialState('disable_appointments', $disableAppointments);
 		$this->initialStateService->provideInitialState('can_subscribe_link', $canSubscribeLink);
-		$this->initialStateService->provideInitialState('categories', $this->categoriesService->getCategories($this->userId));
 		$this->initialStateService->provideInitialState('show_resources', $showResources);
+		$this->initialStateService->provideInitialState('isCirclesEnabled', $isCirclesEnabled && $isCircleVersionCompatible);
+		$this->initialStateService->provideInitialState('publicCalendars', $publicCalendars);
 
 		return new TemplateResponse($this->appName, 'main');
 	}
