@@ -71,6 +71,8 @@ use function json_encode;
  * @method void setDailyMax(?int $max)
  * @method int|null getFutureLimit()
  * @method void setFutureLimit(?int $limit)
+ * @method int|null getCreateTalkRoom()
+ * @method void setCreateTalkRoom(bool $create)
  */
 class AppointmentConfig extends Entity implements JsonSerializable {
 	/** @var string */
@@ -127,6 +129,9 @@ class AppointmentConfig extends Entity implements JsonSerializable {
 	/** @var int|null */
 	protected $futureLimit;
 
+	/** @var bool */
+	protected $createTalkRoom;
+
 	/** @var string */
 	public const VISIBILITY_PUBLIC = 'PUBLIC';
 
@@ -143,6 +148,7 @@ class AppointmentConfig extends Entity implements JsonSerializable {
 		$this->addType('timeBeforeNextSlot', 'int');
 		$this->addType('dailyMax', 'int');
 		$this->addType('futureLimit', 'int');
+		$this->addType('createTalkRoom', 'boolean');
 	}
 
 	/**
@@ -201,11 +207,12 @@ class AppointmentConfig extends Entity implements JsonSerializable {
 			'length' => $this->getLength(),
 			'increment' => $this->getIncrement(),
 			'preparationDuration' => $this->getPreparationDuration(),
-			'followUpDuration' => $this->getFollowupDuration(),
+			'followupDuration' => $this->getFollowupDuration(),
 			'totalLength' => $this->getTotalLength(),
 			'timeBeforeNextSlot' => $this->getTimeBeforeNextSlot(),
 			'dailyMax' => $this->getDailyMax(),
-			'futureLimit' => $this->getFutureLimit()
+			'futureLimit' => $this->getFutureLimit(),
+			'createTalkRoom' => $this->getCreateTalkRoom(),
 		];
 	}
 }
